@@ -84,7 +84,7 @@ impl Unit {
 
     fn increment_from_py(self, v: PyObj, hours_increment_always_ok: bool) -> PyResult<i64> {
         let inc = v
-            .cast::<PyInt>()
+            .cast_allow_subclass::<PyInt>()
             .ok_or_type_err("increment must be an integer")?
             .to_i64()?;
         if inc <= 0 || inc >= 1000 {
@@ -166,14 +166,12 @@ pub(crate) fn parse_args(
         }
         if num_argkwargs > 4 {
             raise_type_err(format!(
-                "round() takes at most 4 arguments, got {}",
-                num_argkwargs
+                "round() takes at most 4 arguments, got {num_argkwargs}"
             ))?;
         }
     } else if num_argkwargs > 3 {
         raise_type_err(format!(
-            "round() takes at most 3 arguments, got {}",
-            num_argkwargs
+            "round() takes at most 3 arguments, got {num_argkwargs}"
         ))?;
     }
     let mut ignore_dst = false;
@@ -185,10 +183,7 @@ pub(crate) fn parse_args(
         for (i, &kwname) in [str_unit, str_increment, str_mode].iter().enumerate() {
             if eq(key, kwname) {
                 if arg_obj[i].replace(value).is_some() {
-                    raise_type_err(format!(
-                        "round() got multiple values for argument {}",
-                        kwname
-                    ))?;
+                    raise_type_err(format!("round() got multiple values for argument {kwname}"))?;
                 }
                 return Ok(true);
             }
